import { UPDATE_EXTENSION } from '@things-factory/export-base'
import { store } from '@operato/shell'
import { Parser } from '@json2csv/plainjs'

async function jsonToCsv({ extension, data, name }) {
  const records = typeof data === 'function' ? await data.call() : data

  const fields = Object.keys(records[0])
  const parser = new Parser({ fields })
  const csv = parser.parse(records)

  const blob = new Blob([csv], { type: 'text/csv;charset=utf-8' })

  // Blob을 URL로 변환
  const blobUrl = URL.createObjectURL(blob)

  const link = document.createElement('a')
  link.href = blobUrl
  link.download = `${name}.csv`

  document.body.appendChild(link)
  link.click()
  document.body.removeChild(link)

  // Blob URL 해제
  URL.revokeObjectURL(blobUrl)
}

export default function bootstrap() {
  store.dispatch({
    type: UPDATE_EXTENSION,
    extensions: {
      csv: {
        export: jsonToCsv
      }
    }
  })
}
